/* ============================================================
 *
 * Copyright (C) 2007-2008 by Kare Sars <kare dot sars at iki dot fi>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This appication is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * ============================================================ */

#include "scandialog.h"

#include <kscan.h>
#include <kglobal.h>
#include <klocale.h>
#include <kdebug.h>
//#include <kconfig.h>
//#include <kglobalsettings.h>
#include <kpluginloader.h>
#include <KMessageBox>

K_PLUGIN_FACTORY( ScanDialogFactory, registerPlugin<ScanDialog>(); )
K_EXPORT_PLUGIN( ScanDialogFactory("kscanplugin") )


///////////////////////////////////////////////////////////////////


ScanDialog::ScanDialog( QWidget *parent, const QVariantList & )
   : KScanDialog( Tabbed, Close|Help, parent )
{

    ksanew = new KSaneIface::KSaneWidget(this);
    addPage(ksanew, i18n("&Scanning") );

    connect(ksanew, SIGNAL(imageReady(QByteArray &, int, int, int, int)),
            this, SLOT(imageReady(QByteArray &, int, int, int, int)));

    openDev = QString();
}


bool ScanDialog::setup()
{
    if(!ksanew) {
        // new failed
        return false;
    }

    if (!openDev.isEmpty()) {
        return true;
    }

    // need to select a scanner
    openDev = ksanew->selectDevice(0);
    if (openDev.isEmpty()) {
       // either no scanner was found or then cancel was pressed.
        return false;
    }
    if (ksanew->openDevice(openDev) == false) {
        // could not open the scanner
        KMessageBox::sorry(0, i18n("Opening the selected scanner failed!"));
        openDev = QString();
        return false;
    }

   return true;
}


ScanDialog::~ScanDialog()
{
}

void ScanDialog::imageReady(QByteArray &data, int w, int h, int bpl, int f)
{
    /* copy the image data into img */
    QImage img = ksanew->toQImage(data, w, h, bpl, (KSaneIface::KSaneWidget::ImageFormat)f);
    emit finalImage(img, nextId());
}


#include "scandialog.moc"
